pub fn deserialize_blinding_factors_from_bytes<C: PrimeOrderCurve>(
bytes: &[u8],
) -> Vec<C::Scalar>Expand description
Helper function to read a Vec of bytes as serialized blinding factors in a manner compatiable with the Orb’s serialization functions.