deserialize_commitment_from_bytes

Function deserialize_commitment_from_bytes 

pub fn deserialize_commitment_from_bytes<C: PrimeOrderCurve>(
    bytes: &[u8],
) -> Vec<C>
Helper function to read a Vec of bytes as a serialized Hyrax commitment, in a manner compatible with the Orb’s serialization functions.