pub struct SerializedImageCommitment {
pub image: Vec<u8>,
pub commitment_bytes: Vec<u8>,
pub blinding_factors_bytes: Vec<u8>,
}Expand description
An image, its serialized commitment, and its serialized blinding factors (serialized as per the
Orb’s serialization functions).
(This is useful since the Vec<u8> representation of the attributes are convenient for receiving
data from the phone app.)
Fields
image: Vec<u8>The image, unpadded.
commitment_bytes: Vec<u8>The commitment to the image, serialized using the curve’s compressed representation.
blinding_factors_bytes: Vec<u8>The blinding factors for the image, serialized in little-endian byte order.